Module beamlit.api.knowledgebases
=================================

Sub-modules
-----------
* beamlit.api.knowledgebases.create_knowledgebase
* beamlit.api.knowledgebases.delete_knowledgebase
* beamlit.api.knowledgebases.get_knowledgebase
* beamlit.api.knowledgebases.list_knowledgebase_revisions
* beamlit.api.knowledgebases.list_knowledgebases
* beamlit.api.knowledgebases.update_knowledgebase